from django.urls import path

from . import views


urlpatterns = [
    # Export permissions
    path('drffp/export/<int:ufp_id>/', views.permissions_export_json, name='drffp-export'),

    # Import permissions
    path('drffp/import/', views.permissions_import_json, name='drffp-import'),
    path('drffp/import/<int:ufp_id>/', views.permissions_import_json, name='drffp-import-ufp'),
]



from django.apps import AppConfig


class FinePermissionsConfig(AppConfig):
    default_auto_field = 'django.db.models.AutoField'
    name = 'rest_framework_fine_permissions'
    verbose_name = 'Rest Framework Fine Permissions'



from rest_framework_fine_permissions.urls import urlpatterns as drffp_urls

from django.contrib import admin
from django.urls import path

urlpatterns = drffp_urls
urlpatterns += [
    path('admin/', admin.site.urls),
]
